import { SerializedError } from "@reduxjs/toolkit";
import { FetchBaseQueryError } from "@reduxjs/toolkit/query";
import { ErrorMessage } from "../../../types/common";

interface BrowserError {
  error: string;
  status: string;
}

const isBrowserError = (error: unknown | BrowserError) => {
  return (
    error != null &&
    typeof error === "object" &&
    "error" in error &&
    typeof (error as BrowserError).status === "string"
  );
};

export const isFetchBaseQueryError = (
  error: unknown
): error is FetchBaseQueryError => {
  return (
    error != null &&
    typeof error === "object" &&
    "status" in error &&
    typeof (error as FetchBaseQueryError).status === "number"
  );
};

export const isErrorWithMessage = (
  error: unknown
): error is { message: string } => {
  return (
    error != null &&
    typeof error === "object" &&
    "message" in error &&
    typeof (error as SerializedError).message === "string"
  );
};

export const getErrorMessage = (
  error: FetchBaseQueryError | SerializedError | BrowserError | unknown
) => {
  if (error) {
    if (isFetchBaseQueryError(error)) {
      const customError = error.data as ErrorMessage;
      if (customError) {
        return customError.description
          ? customError.description
          : customError.error;
      }
    } else if (isErrorWithMessage(error)) {
      return error.message;
    } else if (isBrowserError(error)) {
      const browserError = error as BrowserError;
      return browserError.error;
    }
    return "Unknown error";
  }
  return "Unknown error";
};
